@@ -35,7 +35,11 @@ resp_var <- function(x) {
 }
 
 #' @rdname pred_vars
+#' @importFrom nlme getResponse
 #' @export
 resp_val <- function(x) {
-  as.vector(stats::model.frame(x)[[resp_var(x)]])
+  if (class(x) == "lme")
+    as.vector(nlme::getResponse(x))
+  else
+    as.vector(stats::model.frame(x)[[resp_var(x)]])
 }
